@@ -714,7 +714,7 @@ void service_connection(int fd)
   int status;
 
   while(1) {
-    status = read(fd, &buffer[offset], sizeof(buffer)-offset);
+    status = read(fd, &buffer[offset], sizeof(buffer)-offset-1);
     if (status < 0) {
       write(fd, "Error reading.\n", strlen("Error reading.\n"));
       close(fd);
